@@ -1,23 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtNetwork module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -26,12 +44,22 @@
 
 #include <QtCore/qiodevice.h>
 #include <QtCore/qobject.h>
+#ifndef QT_NO_DEBUG_STREAM
+#include <QtCore/qdebug.h>
+#endif
+
+QT_BEGIN_HEADER
+
+QT_BEGIN_NAMESPACE
 
 QT_MODULE(Network)
 
 class QHostAddress;
+#ifndef QT_NO_NETWORKPROXY
 class QNetworkProxy;
+#endif
 class QAbstractSocketPrivate;
+class QAuthenticator;
 
 class Q_NETWORK_EXPORT QAbstractSocket : public QIODevice
 {
@@ -53,12 +81,21 @@ public:
         HostNotFoundError,
         SocketAccessError,
         SocketResourceError,
-        SocketTimeoutError,
+        SocketTimeoutError,                     /* 5 */
         DatagramTooLargeError,
         NetworkError,
         AddressInUseError,
         SocketAddressNotAvailableError,
-        UnsupportedSocketOperationError,
+        UnsupportedSocketOperationError,        /* 10 */
+        UnfinishedSocketOperationError,
+        ProxyAuthenticationRequiredError,
+        SslHandshakeFailedError,
+        ProxyConnectionRefusedError,
+        ProxyConnectionClosedError,             /* 15 */
+        ProxyConnectionTimeoutError,
+        ProxyNotFoundError,
+        ProxyProtocolError,
+
         UnknownSocketError = -1
     };
     enum SocketState {
@@ -83,6 +120,7 @@ public:
     QAbstractSocket(SocketType socketType, QObject *parent);
     virtual ~QAbstractSocket();
 
+    // ### Qt 5: Make connectToHost() and disconnectFromHost() virtual.
     void connectToHost(const QString &hostName, quint16 port, OpenMode mode = ReadWrite);
     void connectToHost(const QHostAddress &address, quint16 port, OpenMode mode = ReadWrite);
     void disconnectFromHost();
@@ -100,11 +138,13 @@ public:
     QHostAddress peerAddress() const;
     QString peerName() const;
 
+    // ### Qt 5: Make setReadBufferSize() virtual
     qint64 readBufferSize() const;
     void setReadBufferSize(qint64 size);
 
     void abort();
 
+    // ### Qt 5: Make socketDescriptor() and setSocketDescriptor() virtual.
     int socketDescriptor() const;
     bool setSocketDescriptor(int socketDescriptor, SocketState state = ConnectedState,
                              OpenMode openMode = ReadWrite);
@@ -120,6 +160,7 @@ public:
     bool flush();
 
     // for synchronous access
+    // ### Qt 5: Make waitForConnected() and waitForDisconnected() virtual.
     bool waitForConnected(int msecs = 30000);
     bool waitForReadyRead(int msecs = 30000);
     bool waitForBytesWritten(int msecs = 30000);
@@ -136,6 +177,9 @@ Q_SIGNALS:
     void disconnected();
     void stateChanged(QAbstractSocket::SocketState);
     void error(QAbstractSocket::SocketError);
+#ifndef QT_NO_NETWORKPROXY
+    void proxyAuthenticationRequired(const QNetworkProxy &proxy, QAuthenticator *authenticator);
+#endif
 
 protected Q_SLOTS:
     void connectToHostImplementation(const QString &hostName, quint16 port, OpenMode mode = ReadWrite);
@@ -160,12 +204,10 @@ private:
     Q_DECLARE_PRIVATE(QAbstractSocket)
     Q_DISABLE_COPY(QAbstractSocket)
 
-    Q_PRIVATE_SLOT(d_func(), void connectToNextAddress())
-    Q_PRIVATE_SLOT(d_func(), void startConnecting(const QHostInfo &))
-    Q_PRIVATE_SLOT(d_func(), void abortConnectionAttempt())
-    Q_PRIVATE_SLOT(d_func(), void testConnection())
-    Q_PRIVATE_SLOT(d_func(), bool canReadNotification())
-    Q_PRIVATE_SLOT(d_func(), bool canWriteNotification())
+    Q_PRIVATE_SLOT(d_func(), void _q_connectToNextAddress())
+    Q_PRIVATE_SLOT(d_func(), void _q_startConnecting(const QHostInfo &))
+    Q_PRIVATE_SLOT(d_func(), void _q_abortConnectionAttempt())
+    Q_PRIVATE_SLOT(d_func(), void _q_testConnection())
 
 #ifdef QT3_SUPPORT
 public:
@@ -194,4 +236,13 @@ Q_SIGNALS:
 #endif
 };
 
+#ifndef QT_NO_DEBUG_STREAM
+Q_NETWORK_EXPORT QDebug operator<<(QDebug, QAbstractSocket::SocketError);
+Q_NETWORK_EXPORT QDebug operator<<(QDebug, QAbstractSocket::SocketState);
+#endif
+
+QT_END_NAMESPACE
+
+QT_END_HEADER
+
 #endif // QABSTRACTSOCKET_H
