@@ -1,23 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -30,10 +48,12 @@
 #include <QtGui/qicon.h>
 #include <QtGui/qpixmap.h>
 #include <QtGui/qpalette.h>
-#include <QtCore/qobject.h>
+#include <QtGui/qsizepolicy.h>
 
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Gui)
 
 class QAction;
@@ -81,37 +101,40 @@ public:
     virtual QPalette standardPalette() const;
 
     enum StateFlag {
-        State_None    =       0x00000000,
+        State_None =                0x00000000,
 #ifdef QT3_SUPPORT
-        State_Default = State_None,
+        State_Default =             State_None,
 #endif
-        State_Enabled =       0x00000001,
-        State_Raised =        0x00000002,
-        State_Sunken =        0x00000004,
-        State_Off =           0x00000008,
-        State_NoChange =      0x00000010,
-        State_On =            0x00000020,
-        State_DownArrow =     0x00000040,
-        State_Horizontal =    0x00000080,
-        State_HasFocus =      0x00000100,
-        State_Top =           0x00000200,
-        State_Bottom =        0x00000400,
-        State_FocusAtBorder = 0x00000800,
-        State_AutoRaise =     0x00001000,
-        State_MouseOver =     0x00002000,
-        State_UpArrow =       0x00004000,
-        State_Selected =      0x00008000,
-        State_Active =        0x00010000,
-        State_Open =          0x00040000,
-        State_Children =      0x00080000,
-        State_Item =          0x00100000,
-        State_Sibling =       0x00200000,
-        State_Editing =       0x00400000,
+        State_Enabled =             0x00000001,
+        State_Raised =              0x00000002,
+        State_Sunken =              0x00000004,
+        State_Off =                 0x00000008,
+        State_NoChange =            0x00000010,
+        State_On =                  0x00000020,
+        State_DownArrow =           0x00000040,
+        State_Horizontal =          0x00000080,
+        State_HasFocus =            0x00000100,
+        State_Top =                 0x00000200,
+        State_Bottom =              0x00000400,
+        State_FocusAtBorder =       0x00000800,
+        State_AutoRaise =           0x00001000,
+        State_MouseOver =           0x00002000,
+        State_UpArrow =             0x00004000,
+        State_Selected =            0x00008000,
+        State_Active =              0x00010000,
+        State_Window =              0x00020000,
+        State_Open =                0x00040000,
+        State_Children =            0x00080000,
+        State_Item =                0x00100000,
+        State_Sibling =             0x00200000,
+        State_Editing =             0x00400000,
         State_KeyboardFocusChange = 0x00800000,
 #ifdef QT_KEYPAD_NAVIGATION
-        State_HasEditFocus =  0x01000000,
+        State_HasEditFocus =        0x01000000,
 #endif
-        State_ReadOnly =      0x02000000
+        State_ReadOnly =            0x02000000,
+        State_Small =               0x04000000,
+        State_Mini =                0x08000000
     };
     Q_DECLARE_FLAGS(State, StateFlag)
 
@@ -133,7 +156,8 @@ public:
         PE_FrameGroupBox,
         PE_FrameLineEdit,
         PE_FrameMenu,
-        PE_FrameStatusBar,
+        PE_FrameStatusBar, // obsolete
+        PE_FrameStatusBarItem = PE_FrameStatusBar,
         PE_FrameTabWidget,
         PE_FrameWindow,
         PE_FrameButtonBevel,
@@ -154,6 +178,7 @@ public:
         PE_IndicatorBranch,
         PE_IndicatorButtonDropDown,
         PE_IndicatorViewItemCheck,
+        PE_IndicatorItemViewItemCheck = PE_IndicatorViewItemCheck,
         PE_IndicatorCheckBox,
         PE_IndicatorDockWidgetResizeHandle,
         PE_IndicatorHeaderArrow,
@@ -172,6 +197,17 @@ public:
 
         PE_Widget,
 
+        PE_IndicatorColumnViewArrow,
+        PE_IndicatorItemViewItemDrop,
+
+        PE_PanelItemViewItem,
+        PE_PanelItemViewRow, // ### Qt 5: remove
+
+        PE_PanelStatusBar,
+
+        PE_IndicatorTabClose,
+        PE_PanelMenu,
+
         // do not add any values below/greater this
         PE_CustomBase = 0xf000000
     };
@@ -233,6 +269,15 @@ public:
         CE_ComboBoxLabel,
 
         CE_ToolBar,
+        CE_ToolBoxTabShape,
+        CE_ToolBoxTabLabel,
+        CE_HeaderEmptyArea,
+
+        CE_ColumnViewGrip,
+
+        CE_ItemViewItem,
+
+        CE_ShapedFrame,
 
         // do not add any values below/greater than this
         CE_CustomBase = 0xf0000000
@@ -265,7 +310,7 @@ public:
         SE_ProgressBarContents,
         SE_ProgressBarLabel,
 
-
+        // ### Qt 5: These values are unused; eliminate them
         SE_DialogButtonAccept,
         SE_DialogButtonReject,
         SE_DialogButtonApply,
@@ -288,6 +333,7 @@ public:
         SE_TabWidgetRightCorner,
 
         SE_ViewItemCheckIndicator,
+        SE_ItemViewItemCheckIndicator = SE_ViewItemCheckIndicator,
 
         SE_TabBarTearIndicator,
 
@@ -296,6 +342,37 @@ public:
         SE_LineEditContents,
         SE_FrameContents,
 
+        SE_DockWidgetCloseButton,
+        SE_DockWidgetFloatButton,
+        SE_DockWidgetTitleBarText,
+        SE_DockWidgetIcon,
+
+        SE_CheckBoxLayoutItem,
+        SE_ComboBoxLayoutItem,
+        SE_DateTimeEditLayoutItem,
+        SE_DialogButtonBoxLayoutItem, // ### remove
+        SE_LabelLayoutItem,
+        SE_ProgressBarLayoutItem,
+        SE_PushButtonLayoutItem,
+        SE_RadioButtonLayoutItem,
+        SE_SliderLayoutItem,
+        SE_SpinBoxLayoutItem,
+        SE_ToolButtonLayoutItem,
+
+        SE_FrameLayoutItem,
+        SE_GroupBoxLayoutItem,
+        SE_TabWidgetLayoutItem,
+
+        SE_ItemViewItemDecoration,
+        SE_ItemViewItemText,
+        SE_ItemViewItemFocusRect,
+
+        SE_TabBarTabLeftButton,
+        SE_TabBarTabRightButton,
+        SE_TabBarTabText,
+
+        SE_ShapedFrameContents,
+
         // do not add any values below/greater than this
         SE_CustomBase = 0xf0000000
     };
@@ -314,6 +391,7 @@ public:
         CC_Q3ListView,
         CC_Dial,
         CC_GroupBox,
+        CC_MdiControls,
 
         // do not add any values below/greater than this
         CC_CustomBase = 0xf0000000
@@ -371,6 +449,10 @@ public:
         SC_GroupBoxContents =      0x00000004,
         SC_GroupBoxFrame =         0x00000008,
 
+        SC_MdiMinButton     =      0x00000001,
+        SC_MdiNormalButton  =      0x00000002,
+        SC_MdiCloseButton   =      0x00000004,
+
         SC_All =                   0xffffffff
     };
     Q_DECLARE_FLAGS(SubControls, SubControl)
@@ -446,8 +528,11 @@ public:
         PM_DialogButtonsButtonWidth,
         PM_DialogButtonsButtonHeight,
 
-        PM_MDIFrameWidth,
-        PM_MDIMinimizedWidth,
+        PM_MdiSubWindowFrameWidth,
+        PM_MDIFrameWidth = PM_MdiSubWindowFrameWidth,            //obsolete
+        PM_MdiSubWindowMinimizedWidth,
+        PM_MDIMinimizedWidth = PM_MdiSubWindowMinimizedWidth,    //obsolete
+
         PM_HeaderMargin,
         PM_HeaderMarkSize,
         PM_HeaderGripMargin,
@@ -485,6 +570,24 @@ public:
         PM_MessageBoxIconSize,
         PM_ButtonIconSize,
 
+        PM_DockWidgetTitleBarButtonMargin,
+
+        PM_RadioButtonLabelSpacing,
+        PM_LayoutLeftMargin,
+        PM_LayoutTopMargin,
+        PM_LayoutRightMargin,
+        PM_LayoutBottomMargin,
+        PM_LayoutHorizontalSpacing,
+        PM_LayoutVerticalSpacing,
+        PM_TabBar_ScrollButtonOverlap,
+
+        PM_TextCursorWidth,
+
+        PM_TabCloseIndicatorWidth,
+        PM_TabCloseIndicatorHeight,
+
+        PM_ScrollView_ScrollBarSpacing,
+        PM_SubMenuOverlap,
 
         // do not add any values below/greater than this
         PM_CustomBase = 0xf0000000
@@ -517,6 +620,8 @@ public:
         CT_DialogButtons,
         CT_HeaderSection,
         CT_GroupBox,
+        CT_MdiControls,
+        CT_ItemViewItem,
         // do not add any values below/greater than this
         CT_CustomBase = 0xf0000000
     };
@@ -603,6 +708,25 @@ public:
         SH_MessageBox_CenterButtons,
         SH_Menu_SelectionWrap,
         SH_ItemView_MovementWithoutUpdatingSelection,
+        SH_ToolTip_Mask,
+        SH_FocusFrame_AboveWidget,
+        SH_TextControl_FocusIndicatorTextCharFormat,
+        SH_WizardStyle,
+        SH_ItemView_ArrowKeysNavigateIntoChildren,
+        SH_Menu_Mask,
+        SH_Menu_FlashTriggeredItem,
+        SH_Menu_FadeOutOnHide,
+        SH_SpinBox_ClickAutoRepeatThreshold,
+        SH_ItemView_PaintAlternatingRowColorsForEmptyArea,
+	    SH_FormLayoutWrapPolicy,
+        SH_TabWidget_DefaultTabPosition,
+        SH_ToolBar_Movable,
+        SH_FormLayoutFieldGrowthPolicy,
+        SH_FormLayoutFormAlignment,
+        SH_FormLayoutLabelAlignment,
+        SH_ItemView_DrawDelegateFrame,
+        SH_TabBar_CloseButtonPosition,
+        SH_DockWidget_ButtonsHaveFrame,
 
         // Add new style hint values here
 
@@ -675,6 +799,20 @@ public:
         SP_ArrowRight,
         SP_ArrowBack,
         SP_ArrowForward,
+        SP_DirHomeIcon,
+        SP_CommandLink,
+        SP_VistaShield,
+        SP_BrowserReload,
+        SP_BrowserStop,
+        SP_MediaPlay,
+        SP_MediaStop,
+        SP_MediaPause,
+        SP_MediaSkipForward,
+        SP_MediaSkipBackward,
+        SP_MediaSeekForward,
+        SP_MediaSeekBackward,
+        SP_MediaVolume,
+        SP_MediaVolumeMuted,
         // do not add any values below/greater than this
         SP_CustomBase = 0xf0000000
     };
@@ -700,9 +838,21 @@ public:
     static QRect alignedRect(Qt::LayoutDirection direction, Qt::Alignment alignment,
                              const QSize &size, const QRect &rectangle);
 
+    int layoutSpacing(QSizePolicy::ControlType control1,
+                      QSizePolicy::ControlType control2, Qt::Orientation orientation,
+                      const QStyleOption *option = 0, const QWidget *widget = 0) const;
+    int combinedLayoutSpacing(QSizePolicy::ControlTypes controls1,
+                              QSizePolicy::ControlTypes controls2, Qt::Orientation orientation,
+                              QStyleOption *option = 0, QWidget *widget = 0) const;
+
 protected Q_SLOTS:
     QIcon standardIconImplementation(StandardPixmap standardIcon, const QStyleOption *opt = 0,
                                      const QWidget *widget = 0) const;
+    int layoutSpacingImplementation(QSizePolicy::ControlType control1,
+                                    QSizePolicy::ControlType control2,
+                                    Qt::Orientation orientation,
+                                    const QStyleOption *option = 0,
+                                    const QWidget *widget = 0) const;
 
 private:
     Q_DISABLE_COPY(QStyle)
@@ -718,6 +868,8 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(QStyle::SubControls)
 Q_GUI_EXPORT QDebug operator<<(QDebug debug, QStyle::State state);
 #endif
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QSTYLE_H
